using System;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Configuration;

namespace CSSamples.Samples.MapShapes
{
    public partial class TrackShapeFinishedEvent : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
                Map1.CurrentExtent = new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962);
                Map1.MapUnit = GeographyUnit.Meter;

                Map1.MapTools.OverlaySwitcher.Enabled = true;
                Map1.MapTools.MouseCoordinate.Enabled = true;

                GoogleOverlay google = new GoogleOverlay("Google Map");
                google.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["GoogleUri"]);
                google.GoogleMapType = GoogleMapType.Normal;

                WorldMapKitWmsWebOverlay thinkGeoMap = new WorldMapKitWmsWebOverlay("ThinkGeo Map");
                thinkGeoMap.Projection = WorldMapKitProjection.SphericalMercator;

                Map1.CustomOverlays.Add(thinkGeoMap);
                Map1.CustomOverlays.Add(google);

                InMemoryFeatureLayer shapeLayer = new InMemoryFeatureLayer();
                shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.FromArgb(180, 102, 255, 102), 10, GeoColor.StandardColors.DarkGreen, 1);
                shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.Green, 4, true);
                shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(180, 102, 255, 102), GeoColor.StandardColors.DarkGreen, 1);
                shapeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                shapeLayer.DrawingQuality = DrawingQuality.HighQuality;

                LayerOverlay dynamicOverlay = new LayerOverlay("DynamicOverlay");
                dynamicOverlay.IsBaseOverlay = false;
                dynamicOverlay.Layers.Add("shapeLayer", shapeLayer);
                Map1.CustomOverlays.Add(dynamicOverlay);
            }
        }

        protected void buttonDrawPoint_Click(object sender, ImageClickEventArgs e)
        {
            Map1.EditOverlay.TrackMode = TrackMode.Point;
        }

        protected void buttonDrawLine_Click(object sender, ImageClickEventArgs e)
        {
            Map1.EditOverlay.TrackMode = TrackMode.Line;
        }

        protected void buttonDrawRectangle_Click(object sender, ImageClickEventArgs e)
        {
            Map1.EditOverlay.TrackMode = TrackMode.Rectangle;
        }

        protected void buttonDrawSquare_Click(object sender, ImageClickEventArgs e)
        {
            Map1.EditOverlay.TrackMode = TrackMode.Square;
        }

        protected void buttonDrawPolygon_Click(object sender, ImageClickEventArgs e)
        {
            Map1.EditOverlay.TrackMode = TrackMode.Polygon;
        }

        protected void buttonDrawCircle_Click(object sender, ImageClickEventArgs e)
        {
            Map1.EditOverlay.TrackMode = TrackMode.Circle;
        }

        protected void buttonDrawEllipse_Click(object sender, ImageClickEventArgs e)
        {
            Map1.EditOverlay.TrackMode = TrackMode.Ellipse;
        }

        protected void Map1_TrackShapeFinished(object sender, EventArgs e)
        {
            LayerOverlay dynamicOverlay = (LayerOverlay)Map1.CustomOverlays["DynamicOverlay"];
            InMemoryFeatureLayer shapeLayer = (InMemoryFeatureLayer)dynamicOverlay.Layers["shapeLayer"];

            foreach (Feature feature in Map1.EditOverlay.Features)
            {
                shapeLayer.InternalFeatures.Add(feature.Id, feature);
            }

            Map1.EditOverlay.Features.Clear();
            dynamicOverlay.Redraw();
        }
    }
}
